@@ -1,15 +1,13 @@
 use strict;
 use warnings;
 package App::Nopaste;
-BEGIN {
-  $App::Nopaste::AUTHORITY = 'cpan:SARTAK';
-}
-# git description: 0.94-3-g98eeedd
-$App::Nopaste::VERSION = '0.95';
+# git description: 0.96-13-gf396393
+$App::Nopaste::VERSION = '0.97';
 
 use 5.008003;
 use Module::Pluggable search_path => 'App::Nopaste::Service';
 use Class::Load 'load_class';
+use namespace::clean;
 
 use base 'Exporter';
 our @EXPORT_OK = 'nopaste';
@@ -84,12 +82,19 @@ sub nopaste {
 }
 
 1;
-
 __END__
 
+=pod
+
+=for stopwords nopaste pastebin
+
 =head1 NAME
 
-App::Nopaste - easy access to any pastebin
+App::Nopaste - Easy access to any pastebin
+
+=head1 VERSION
+
+version 0.97
 
 =head1 SYNOPSIS
 
@@ -175,10 +180,9 @@ Shawn M Moore, C<sartak@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2010 Shawn M Moore.
+Copyright 2008- Shawn M Moore.
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself.
 
 =cut
-
