@@ -1,10 +1,7 @@
 use strict;
 use warnings;
 package App::Nopaste::Service;
-BEGIN {
-  $App::Nopaste::Service::AUTHORITY = 'cpan:SARTAK';
-}
-$App::Nopaste::Service::VERSION = '0.95';
+$App::Nopaste::Service::VERSION = '0.97';
 use WWW::Mechanize;
 
 sub available         { 1 }
@@ -93,10 +90,21 @@ sub return {
     return (1, $link->url);
 }
 
+1;
+__END__
+
+=pod
+
+=for stopwords pastebot XXX chan desc lang mech nopaste canonicalization
+
 =head1 NAME
 
 App::Nopaste::Service - base class for nopaste services
 
+=head1 VERSION
+
+version 0.97
+
 =head1 SYNOPSIS
 
     package App::Nopaste::Service::Shadowcat;
@@ -174,6 +182,3 @@ pasted text.
 Shawn M Moore, C<< <sartak at gmail.com> >>
 
 =cut
-
-1;
-
